=======
History
=======

0.1.0 (2023-07-13)
------------------

* First release on PyPI.

0.2.0 (2023-07-26)
------------------

* Added function to retrieve defined indicams for user, in order to be able to test authentication without
  requiring a device definition to be entered at the authentication step.

0.3.0 (2023-07-26)
------------------

* Replaced the indicam listing function with an explicit connection test function.
